@@ -15,7 +15,9 @@ add_annotation_to_bars <- function(x, y, z, dodged = 0, plt, thresh = 0.07,
                                    angle = 90, 
                                    hjust = c("left", "right"), 
                                    size = 24, inherit.aes = FALSE, 
-                                   fill = NULL, parse = FALSE){
+                                   fill = NULL, parse = FALSE, 
+                                   label_color = NULL, 
+                                   label_size = NULL){
  
   # if any zero length characters, replace with double quotes
   z[nchar(z) == 0] <- NA
@@ -54,22 +56,23 @@ add_annotation_to_bars <- function(x, y, z, dodged = 0, plt, thresh = 0.07,
   # add white labels at the top of the bigger bars
   if(nrow(label_white) > 0){
     plt <- plt + suppressWarnings(
-      geom_fit_text(aes(x = x, y = y, 
-                        label = z, 
-                        group = fill, 
-                        ymin = 0, ymax = y),
-                    data = label_white,
-                    colour = "white",
-                    angle = angle,
-                    inherit.aes = inherit.aes,
-                    na.rm = TRUE,
-                    size = 12,
-                    min.size = 6,
-                    place = "top",
-                    contrast = TRUE,
-                    position = "dodge",
-                    outside = FALSE, 
-                    padding.y = grid::unit(2, "mm"))
+      geom_fit_text(
+        aes(x = x, y = y, 
+            label = z, 
+            group = fill, 
+            ymin = 0, ymax = y),
+        data = label_white,
+        color = 'white',
+        angle = angle,
+        inherit.aes = inherit.aes,
+        na.rm = TRUE,
+        size = ifelse(is.null(label_size), 12, label_size),
+        min.size = 6,
+        place = "top",
+        contrast = TRUE,
+        position = "dodge",
+        outside = FALSE, 
+        padding.y = grid::unit(2, "mm"))
     )
   }
   # add grey labels to relatively short bars, if any
@@ -83,11 +86,11 @@ add_annotation_to_bars <- function(x, y, z, dodged = 0, plt, thresh = 0.07,
                         ymin = y, 
                         ymax = ymax),
                     data = label_grey,
-                    colour = "lightsteelblue4",
+                    colour = ifelse(is.null(label_color), "lightsteelblue4", label_color[2]),
                     angle = angle,
                     inherit.aes = inherit.aes,
                     na.rm = TRUE,
-                    size = 12,
+                    size = ifelse(is.null(label_size), 12, label_size),
                     place = "bottom",
                     min.size = 8,
                     contrast = TRUE,
@@ -108,13 +111,13 @@ add_annotation_to_bars <- function(x, y, z, dodged = 0, plt, thresh = 0.07,
                         ymin = 0,
                         ymax = y),
                     data = label_zero,
-                    colour = "lightsteelblue4",
+                    colour = ifelse(is.null(label_color), "lightsteelblue4", label_color[2]),
                     angle = angle,
                     inherit.aes = inherit.aes,
                     na.rm = TRUE,
-                    size = 12,
-                    place = "bottom",
                     min.size = 8,
+                    size = ifelse(is.null(label_size), 12, label_size),
+                    place = "bottom",
                     contrast = TRUE,
                     position = "dodge",
                     outside = TRUE, 
