@@ -8,8 +8,6 @@
 #' @param df1 A dataframe.
 #' @param df2 An optional second data frame for comparing categorical levels.  
 #' Defaults to \code{NULL}.
-#' @param show_plot (Deprecated) Logical flag indicating whether a plot should be shown.  
-#' Superseded by the function \code{show_plot()} and will be dropped in a future version.
 #' @return A tibble summarising or comparing the categorical features 
 #' in one or a pair of dataframes.
 #' 
@@ -71,7 +69,7 @@
 #' @importFrom progress progress_bar
 #' @importFrom Rcpp compileAttributes
 
-inspect_cat <- function(df1, df2 = NULL, show_plot = FALSE){
+inspect_cat <- function(df1, df2 = NULL){
   
   # perform basic column check on dataframe input
   input_type <- check_df_cols(df1, df2)
@@ -149,6 +147,5 @@ inspect_cat <- function(df1, df2 = NULL, show_plot = FALSE){
   }
   attr(out, "type")     <- list(method = "cat", input_type = input_type)
   attr(out, "df_names") <- df_names
-  if(show_plot) plot_deprecated(out)
   return(out)
 }
